@@ -4,6 +4,8 @@ import os
 import tempfile
 from datetime import datetime
 from time import strftime
+import pandas as pd
+
 from elasticsearch import Elasticsearch
 from cloud_governance.common.aws.s3.s3_operations import S3Operations
 from cloud_governance.common.aws.price.price import AWSPrice
@@ -52,6 +54,30 @@ class ESOperations:
                 with open(os.path.join(temp_local_directory, file_name)) as f:
                     return f.read()
 
+    @staticmethod
+    def __get_cluster_cost(data):
+        """
+        This method aggregate cluster cost data
+        @param data:
+        @return:
+        """
+        # aggregate ec2/ebs cluster cost data
+        resource_data = [item.split('|') for item in data['resources_list']]
+        df = pd.DataFrame(resource_data)
+        # cost column: remove space
+        df[df.columns[-2]] = df[df.columns[-2]].str.strip()
+        # cost column: change to float
+        df[df.columns[-2]] = df[df.columns[-2]].astype(float)
+        cluster_cost = df.groupby(df.columns[-1])[df.columns[-2]].sum()
+        cluster_cost_results = []
+        # cluster | cost
+        for index_df, item_df in cluster_cost.items():
+            if index_df == '  ':
+                cluster_cost_results.append(f'other | {item_df} ')
+            else:
+                cluster_cost_results.append(f'{index_df} | {item_df} ')
+        return cluster_cost_results
+
     def __get_resource_cost(self, resource: str, item_data: dict):
         """
         This method calculate ec2 cost from launch time or ebs per month in $
@@ -61,11 +87,6 @@ class ESOperations:
             # Get current price for a given 'running' instance, region and os
             ec2_type_cost = '0'
             try:
-                # walk around for NA values in eu-central-1
-                # if self.__region == 'eu-central-1':
-                #     curr_region = 'us-east-1'
-                # else:
-                #     curr_region = self.__region
                 ec2_type_cost = self.__aws_price.get_price(self.__aws_price.get_region_name('us-east-1'),
                                                             item_data['InstanceType'], 'Linux')
             except:
@@ -105,9 +126,8 @@ class ESOperations:
             data_list = json.loads(data)
             # if json folding in list need to extract it
             if type(data_list) == list:
-                # resources_list\resources_name_list is a list of ids\names that was triggered by policy
-                data_dict = {'resources_list': [], 'resources_name_list': []}
-                # resources_name_list is a list of resources name
+                # resources_list is a list of items that was triggered by policy
+                data_dict = {'resources_list': []}
                 for i, item in enumerate(data_list):
                     ec2_ebs_name = ''
                     gitleaks_leakurl = ''
@@ -121,7 +141,6 @@ class ESOperations:
                     if item.get('Tags'):
                         for val in item['Tags']:
                             if val['Key'] == 'Name':
-                                data_dict['resources_name_list'].append(val['Value'])
                                 ec2_ebs_name = val['Value']
                             if val['Value'] == 'owned':
                                 cluster_owned = val['Key']
@@ -140,6 +159,10 @@ class ESOperations:
                         gitleaks_leakurl = item.get('leakURL')
                     if item.get('email'):
                         data_dict['resources_list'].append(f"{item.get('email')} | {gitleaks_leakurl}")
+
+                # get cluster cost data only for ec2 and ebs
+                if ec2_ebs_name:
+                    data_dict['cluster_cost_data'] = self.__get_cluster_cost(data=data_dict)
                 data = data_dict
         # no data for policy
         else:
